%define maj     3
%define libname     %mklibname openssl %{maj}
%define develname   %mklibname openssl -d
%define staticname  %mklibname openssl -s -d

Summary:    Secure Sockets Layer communications libs & utils
Name:       openssl
Version:    3.3.3
Release:    %mkrel 1
License:    ASL 2.0
Group:      System/Libraries
URL:        https://openssl-library.org/
Source0:    https://github.com/%{name}/%{name}/releases/download/%{name}-%{version}/%{name}-%{version}.tar.gz
Source1:    https://github.com/%{name}/%{name}/releases/download/%{name}-%{version}/%{name}-%{version}.tar.gz.asc
Source2:    Makefile.certificate
Source3:    genpatches
Source4:    openssl-thread-test.c
Source6:    make-dummy-cert
Source7:    renew-dummy-cert
Source9:    configuration-switch.h
Source10:   configuration-prefix.h
Source14:   0025-for-tests.patch

# fedora patches
# Patches exported from source git
# Aarch64 and ppc64le use lib64
Patch1: 0001-Aarch64-and-ppc64le-use-lib64.patch
# Use more general default values in openssl.cnf
Patch2: 0002-Use-more-general-default-values-in-openssl.cnf.patch
# Do not install html docs
Patch3: 0003-Do-not-install-html-docs.patch
# Override default paths for the CA directory tree
Patch4: 0004-Override-default-paths-for-the-CA-directory-tree.patch
# apps/ca: fix md option help text
Patch5: 0005-apps-ca-fix-md-option-help-text.patch
# Disable signature verification with totally unsafe hash algorithms
Patch6: 0006-Disable-signature-verification-with-totally-unsafe-h.patch
# Add support for PROFILE=SYSTEM system default cipherlist
Patch7: 0007-Add-support-for-PROFILE-SYSTEM-system-default-cipher.patch
# Add FIPS_mode() compatibility macro
Patch8: 0008-Add-FIPS_mode-compatibility-macro.patch
# Add check to see if fips flag is enabled in kernel
#Patch9: 0009-Add-Kernel-FIPS-mode-flag-support.patch
# Instead of replacing ectest.c and ec_curve.c, add the changes as a patch so
# that new modifications made to these files by upstream are not lost.
Patch10:  0010-Add-changes-to-ectest-and-eccurve.patch
# remove unsupported EC curves
Patch11: 0011-Remove-EC-curves.patch
Patch12: 0012-Disable-explicit-ec.patch
Patch13: 0013-skipped-tests-EC-curves.patch
# Instructions to load legacy provider in openssl.cnf
Patch24: 0024-load-legacy-prov.patch
# Selectively disallow SHA1 signatures rhbz#2070977
Patch49: 0049-Allow-disabling-of-SHA1-signatures.patch

# Upstream patches

# Mageia patches
Patch1000: 1000-mga-fix-build-with-gcc14.patch

Requires:   %{libname} = %{version}-%{release}
Requires:   rootcerts
BuildRequires:  multiarch-utils >= 1.0.3
BuildRequires:  chrpath
BuildRequires:  pkgconfig(zlib)
BuildRequires:  pkgconfig(libsctp)
BuildRequires:  git
%ifarch %{arm}
BuildRequires:  libatomic-devel
%endif
# (tv) for test suite:
BuildRequires:  bc

%description
The openssl certificate management tool and the shared libraries that provide
various encryption and decryption algorithms and protocols, including DES, RC4,
RSA and SSL.

%package -n %{libname}
Summary:    Secure Sockets Layer communications libs
Group:      System/Libraries
Requires:   crypto-policies
Provides:   %{libname} = %{version}-%{release}

%description -n %{libname}
The libraries files are needed for various cryptographic algorithms
and protocols, including DES, RC4, RSA and SSL.

%package -n %{develname}
Summary:    Secure Sockets Layer communications libs & headers & utils
Group:      Development/Other
Requires:   %{libname} = %{version}-%{release}
Provides:   libopenssl-devel
Provides:   %{name}-devel = %{version}-%{release}

%description -n %{develname}
The libraries and include files needed to compile apps with support
for various cryptographic algorithms and protocols, including DES, RC4, RSA
and SSL.

%package -n %{staticname}
Summary:    Secure Sockets Layer communications static libs
Group:      Development/Other
Requires:   %{develname} = %{version}-%{release}
Provides:   libopenssl-static-devel
Provides:   %{name}-static-devel = %{version}-%{release}

%description -n %{staticname}
The static libraries needed to compile apps with support for various
cryptographic algorithms and protocols, including DES, RC4, RSA and SSL.

%package    perl
Summary:    Perl scripts provided with OpenSSL
Group:      System/Libraries
Requires:   %{name} = %{version}-%{release}
Conflicts:  %name <= 1.0.2h-1.mga6

%description    perl
OpenSSL is a toolkit for supporting cryptography. The openssl-perl
package provides Perl scripts for converting certificates and keys
from other formats to the formats used by the OpenSSL toolkit.

%prep
%autosetup -S git -n %{name}-%{version}

%build
%serverbuild

# Figure out which flags we want to use.
# default
sslarch=%{_os}-%{_target_cpu}
%ifarch %ix86
sslarch=linux-elf
if ! echo %{_target} | grep -q i[56]86 ; then
    sslflags="no-asm 386"
fi
%endif
%ifarch x86_64
sslflags=enable-ec_nistp_64_gcc_128
%endif
%ifarch %{arm}
sslarch=linux-armv4
%endif

# Add -Wa,--noexecstack here so that libcrypto's assembler modules will be
# marked as not requiring an executable stack.
# Also add -DPURIFY to make using valgrind with openssl easier as we do not
# want to depend on the uninitialized memory as a source of entropy anyway.
RPM_OPT_FLAGS="$RPM_OPT_FLAGS -Wa,--noexecstack -Wa,--generate-missing-build-notes=yes -DPURIFY $RPM_LD_FLAGS"

export HASHBANGPERL=/usr/bin/perl

# ia64, x86_64, ppc, ppc64 are OK by default
# Configure the build tree.  Override OpenSSL defaults with known-good defaults
# usable on all platforms.  The Configure script already knows to use -fPIC and
# RPM_OPT_FLAGS, so we can skip specifiying them here.
./Configure \
    --prefix=%{_prefix} --openssldir=%{_sysconfdir}/pki/tls ${sslflags} \
    --system-ciphers-file=%{_sysconfdir}/crypto-policies/back-ends/openssl.config \
     zlib enable-camellia enable-seed enable-rfc3779 enable-sctp \
     enable-cms enable-md2 enable-rc5 enable-ktls enable-fips \
     no-mdc2 no-ec2m no-sm2 no-sm4 no-quic \
     shared ${sslarch} $RPM_OPT_FLAGS '-DDEVRANDOM="\"/dev/urandom\""'

make all

# Clean up the .pc files
for i in libcrypto.pc libssl.pc openssl.pc ; do
    sed -i '/^Libs.private:/{s/-L[^ ]* //;s/-Wl[^ ]* //}' $i
done

%check

(sysctl net.sctp.addip_enable=1 && sysctl net.sctp.auth_enable=1) || \
(echo 'Failed to enable SCTP AUTH chunks, disabling SCTP for tests...' &&
    sed '/"msan" => "default",/a\ \ "sctp" => "default",' configdata.pm > configdata.pm.new && \
    touch -r configdata.pm configdata.pm.new && \
    mv -f configdata.pm.new configdata.pm)

# We must revert patch4 before tests otherwise they will fail
patch -p1 -R < %{PATCH4}
# We must disable default provider before tests otherwise they will fail
patch -p1 < %{SOURCE14}

export OPENSSL_ENABLE_MD5_VERIFY=
export OPENSSL_SYSTEM_CIPHERS_OVERRIDE=xyz_nonexistent_file

make test

%install
%make_install

# make the rootcerts dir
install -d %{buildroot}%{_sysconfdir}/pki/tls/rootcerts

# Install a makefile for generating keys and self-signed certs, and a script
# for generating them on the fly.
mkdir -p %{buildroot}%{_sysconfdir}/pki/tls/certs
install -m 644 %{SOURCE2} %{buildroot}%{_sysconfdir}/pki/tls/certs/Makefile
install -m 755 %{SOURCE6} %{buildroot}%{_bindir}/make-dummy-cert
install -m 755 %{SOURCE7} %{buildroot}%{_bindir}/renew-dummy-cert

# Move runable perl scripts to bindir
mv %{buildroot}%{_sysconfdir}/pki/tls/misc/*.pl %{buildroot}%{_bindir}
mv %{buildroot}%{_sysconfdir}/pki/tls/misc/tsget %{buildroot}%{_bindir}

# Rename man pages so that they don't conflict with other system man pages.
pushd %{buildroot}%{_mandir}
mv man5/config.5ossl man5/openssl.cnf.5
popd

install -d %{buildroot}%{_sysconfdir}/pki/CA
install -d %{buildroot}%{_sysconfdir}/pki/CA/private
install -d %{buildroot}%{_sysconfdir}/pki/CA/certs
install -d %{buildroot}%{_sysconfdir}/pki/CA/crl
install -d %{buildroot}%{_sysconfdir}/pki/CA/newcerts

rm -f %{buildroot}%{_sysconfdir}/pki/tls/openssl.cnf.dist
rm -f %{buildroot}%{_sysconfdir}/pki/tls/ct_log_list.cnf.dist
%ifarch i686
rm -f %{buildroot}%{_sysconfdir}/pki/tls/fipsmodule.cnf
%endif

%multiarch_includes %{buildroot}%{_includedir}/openssl/opensslconf.h

# nuke rpath
chrpath -d %{buildroot}%{_bindir}/openssl

# Fix libdir.
for i in %{buildroot}%{_libdir}/pkgconfig/*.pc; do
    sed -i 's,^libdir=${exec_prefix}/lib$,libdir=${exec_prefix}/%{_lib},g' $i
done

# adjust ssldir
perl -pi -e "s|^\\\$CATOP\=\".*|\\\$CATOP\=\"%{_sysconfdir}/pki/tls\";|g" %{buildroot}%{_bindir}/CA.pl
perl -pi -e "s|\./demoCA|%{_sysconfdir}/pki/tls|g" %{buildroot}%{_sysconfdir}/pki/tls/openssl.cnf

%files
%doc LICENSE.txt NEWS.md README.md
%dir %{_sysconfdir}/pki
%dir %{_sysconfdir}/pki/tls
%dir %{_sysconfdir}/pki/tls/certs
%dir %{_sysconfdir}/pki/tls/misc
%dir %{_sysconfdir}/pki/tls/private
%dir %{_sysconfdir}/pki/tls/rootcerts
%config(noreplace) %{_sysconfdir}/pki/tls/openssl.cnf
%config(noreplace) %{_sysconfdir}/pki/tls/ct_log_list.cnf
%ifnarch i686
%config(noreplace) %{_sysconfdir}/pki/tls/fipsmodule.cnf
%endif
%{_sysconfdir}/pki/tls/certs/Makefile
%{_bindir}/make-dummy-cert
%{_bindir}/renew-dummy-cert
%{_bindir}/openssl
%{_mandir}/man[157]/*
%exclude %{_mandir}/man1*/*rehash*
%exclude %{_mandir}/man1*/*.pl*
%exclude %{_mandir}/man1*/*tsget*

%files -n %{libname}
%doc LICENSE.txt
%{_libdir}/lib*.so.%{maj}
%{_libdir}/engines-%{maj}
%{_libdir}/ossl-modules

%files -n %{develname}
%doc CHANGES.md doc/dir-locals.example.el doc/openssl-c-indent.el
%dir %{_includedir}/openssl
%multiarch %{multiarch_includedir}/openssl/opensslconf.h
%{_includedir}/openssl
%{_libdir}/lib*.so
%{_mandir}/man3/*
%{_libdir}/pkgconfig/*.pc
%{_libdir}/cmake/OpenSSL/

%files -n %{staticname}
%{_libdir}/lib*.a

%files perl
%{_bindir}/c_rehash
%{_bindir}/*.pl
%{_bindir}/tsget
%{_mandir}/man1*/*rehash*
%{_mandir}/man1*/*.pl*
%{_mandir}/man1*/*tsget*
%dir %{_sysconfdir}/pki/CA
%dir %{_sysconfdir}/pki/CA/private
%dir %{_sysconfdir}/pki/CA/certs
%dir %{_sysconfdir}/pki/CA/crl
%dir %{_sysconfdir}/pki/CA/newcerts


%changelog
* Wed Feb 12 2025 ns80 <ns80> 3.3.3-1.mga10
+ Revision: 2147751
- new version 3.3.3 for CVE-2024-12797 (mga#34010)

* Thu Jan 23 2025 ns80 <ns80> 3.3.2-3.mga10
+ Revision: 2140761
- add upstream patch for CVE-2024-13176 (mga#33942)

* Thu Nov 07 2024 ns80 <ns80> 3.3.2-2.mga10
+ Revision: 2112928
- add upstream patch for CVE-2024-9143 (mga#33650)

* Fri Sep 06 2024 ns80 <ns80> 3.3.2-1.mga10
+ Revision: 2093393
- new version 3.3.2 for CVE-2024-6119 (mga#33520)
+ wally <wally>
- own CMake config dir

* Tue Jul 09 2024 ns80 <ns80> 3.3.1-1.mga10
+ Revision: 2080454
- disable QUIC
- new version 3.3.1

* Thu Jun 27 2024 ns80 <ns80> 3.1.6-1.mga10
+ Revision: 2077334
- add upstream patch for CVE-2024-5535 (mga#33337)
- new version 3.1.6

* Thu May 30 2024 ns80 <ns80> 3.1.5-2.mga10
+ Revision: 2068718
- add upstream patches for CVE-2024-4603 and CVE-2024-4741 (mga#33224)

* Wed Apr 10 2024 ns80 <ns80> 3.1.5-1.mga10
+ Revision: 2056331
- update to 3.1.5 and add an upstream patch for CVE-2024-2511 (mga#33078)

* Fri Apr 05 2024 wally <wally> 3.1.4-3.mga10
+ Revision: 2054668
- basesystem rebuild for i686

* Tue Jan 30 2024 ns80 <ns80> 3.1.4-2.mga10
+ Revision: 2036250
- add upstream patches for CVE-2023-5678, CVE-2023-6129, CVE-2023-6237 and CVE-2024-0727 (mga#32498)

* Thu Nov 02 2023 ns80 <ns80> 3.1.4-1.mga10
+ Revision: 2003611
- add patch 0013-skipped-tests-EC-curves
- new version 3.1.4 for CVE-2023-5363 (mga#32452)
- new version 3.1.3

* Thu Sep 21 2023 ns80 <ns80> 3.0.11-1.mga10
+ Revision: 1989131
- new version 3.0.11

* Tue Aug 29 2023 ns80 <ns80> 3.0.10-1.mga10
+ Revision: 1980867
- new version 3.0.10 for CVE-2023-2975, CVE-2023-3446 and CVE-2023-3817 (mga#32112)

* Thu Jun 01 2023 ns80 <ns80> 3.0.9-1.mga9
+ Revision: 1960434
- new version 3.0.9 for CVE-2023-2650 (mga#31981)

* Fri Apr 21 2023 ns80 <ns80> 3.0.8-3.mga9
+ Revision: 1953814
- backport an upstream patch for CVE-2023-1255

* Fri Mar 31 2023 ns80 <ns80> 3.0.8-2.mga9
+ Revision: 1951064
- backport upstream patches for CVE-2023-046[4-6] (mga#31526)

* Fri Mar 10 2023 ns80 <ns80> 3.0.8-1.mga9
+ Revision: 1948520
- new version 3.0.8 for CVE-2022-4203, CVE-2022-4304, CVE-2022-4450, CVE-2023-021[5-7], CVE-2023-0286, CVE-2023-0401 (mga#31526)

* Fri Jan 20 2023 ns80 <ns80> 3.0.5-4.mga9
+ Revision: 1934473
- add a patch from openSUSE for CVE-2022-3996 (mga#31308)

* Sun Nov 27 2022 wally <wally> 3.0.5-3.mga9
+ Revision: 1911558
- add Fedora patches to allow disabling SHA1 signatures by introducing a new
  configuration option in the alg_section named 'rh-allow-sha1-signatures'

* Tue Nov 01 2022 luigiwalser <luigiwalser> 3.0.5-2.mga9
+ Revision: 1901076
- add upstream patch to fix CVE-2022-3358
- add patch from fedora to fix CVE-2022-3602 and CVE-2022-3786

* Tue Jul 05 2022 luigiwalser <luigiwalser> 3.0.5-1.mga9
+ Revision: 1867816
- 3.0.5 (fixes CVE-2022-2274)

* Tue Jun 21 2022 ns80 <ns80> 3.0.4-1.mga9
+ Revision: 1865364
- new version 3.0.4 for CVE-2022-2068 (mga#30573)

* Wed May 04 2022 ns80 <ns80> 3.0.3-1.mga9
+ Revision: 1856201
- new version 3.0.3 for CVE-2022-1292, CVE-2022-1343, CVE-2022-1434, CVE-2022-1473 (mga#30369)

* Wed Mar 16 2022 ns80 <ns80> 3.0.2-1.mga9
+ Revision: 1794372
- new version 3.0.2 for CVE-2021-4044 (mga#29768) and CVE-2022-0778 (mga#30174)

* Fri Oct 01 2021 guillomovitch <guillomovitch> 3.0.0-2.mga9
+ Revision: 1747286
- try to fix build dependencies on arm platform

* Wed Sep 29 2021 guillomovitch <guillomovitch> 3.0.0-1.mga9
+ Revision: 1746892
- new version 3.0.0

* Mon Aug 30 2021 ns80 <ns80> 1.1.1l-1.mga9
+ Revision: 1743558
- new version 1.1.1l for CVE-2021-371[12] (mga#29409)

* Fri Mar 26 2021 ns80 <ns80> 1.1.1k-1.mga9
+ Revision: 1710444
- new version 1.1.1k for CVE-2021-3449 and CVE-2021-3450 (mga#28640)

* Sat Feb 27 2021 neoclust <neoclust> 1.1.1j-1.mga9
+ Revision: 1693004
- New version 1.1.1j (mga#28383)

* Thu Dec 10 2020 ns80 <ns80> 1.1.1i-1.mga8
+ Revision: 1655126
- new version 1.1.1i for CVE-2020-1971 (mga#27791)

* Wed Nov 11 2020 luigiwalser <luigiwalser> 1.1.1h-1.mga8
+ Revision: 1644759
- 1.1.1h
- drop patch 43 (as in fedora)
- update patches 37, 46, 47, 49 from fedora

* Wed Apr 22 2020 ns80 <ns80> 1.1.1g-1.mga8
+ Revision: 1570996
- new version 1.1.1g for CVE-2020-1967 (mga#26523)

* Wed Apr 01 2020 ns80 <ns80> 1.1.1f-1.mga8
+ Revision: 1563917
- new version 1.1.1f

* Mon Mar 23 2020 ns80 <ns80> 1.1.1e-1.mga8
+ Revision: 1559128
- new version 1.1.1e

* Tue Feb 18 2020 umeabot <umeabot> 1.1.1d-3.mga8
+ Revision: 1541560
- Mageia 8 Mass Rebuild

* Sun Dec 29 2019 ns80 <ns80> 1.1.1d-2.mga8
+ Revision: 1474701
- add upstream patch for CVE-2019-1551 (mga#25977)

* Tue Nov 26 2019 ns80 <ns80> 1.1.1d-1.mga8
+ Revision: 1462911
- new version of patch upstream-sync
- sync ec_curve.c and ectest.c with fedora
- rediff patches
- new version 1.1.1d (mga#24888)

* Sat Aug 24 2019 guillomovitch <guillomovitch> 1.1.1c-1.mga8
+ Revision: 1431659
- new version 1.1.1
- sync patch set with Fedora
- drop unappliable patch#6 (Brazilian government OTHERNAME X509v3 field)
- add sctp support

* Thu Nov 22 2018 ns80 <ns80> 1.1.0j-1.mga7
+ Revision: 1333303
- new version 1.1.0j for CVE-2018-073[45] and CVE-2018-5407 (mga#23870)

* Mon Sep 03 2018 ns80 <ns80> 1.1.0i-3.mga7
+ Revision: 1256516
- disable tests for i586 as it fails on BS
- new version 1.1.0i for CVE-2018-073[27] (mga#22934)

* Sun May 13 2018 wally <wally> 1.1.0h-2.mga7
+ Revision: 1228710
- add patch from upstream to fix missing quotes in c_rehash (mga#23024)

* Sat Mar 31 2018 luigiwalser <luigiwalser> 1.1.0h-1.mga7
+ Revision: 1213922
- 1.1.0h
- rediff patches 32, 39, and 40 (from fedora)

* Fri Mar 02 2018 daviddavid <daviddavid> 1.1.0g-3.mga7
+ Revision: 1206027
- fix more dangling link (mga#22666)

* Sun Feb 25 2018 daviddavid <daviddavid> 1.1.0g-2.mga7
+ Revision: 1204885
- fix dangling link (mga#22228)

* Sun Nov 05 2017 luigiwalser <luigiwalser> 1.1.0g-1.mga7
+ Revision: 1176041
- 1.1.0g
- rediff patches 1, 23, 36, and 38
- remove upstreamed patches 43, 70, and 71
- do not enable sctp

* Wed Aug 02 2017 guillomovitch <guillomovitch> 1.1.0f-1.mga7
+ Revision: 1133938
- new version 1.1.0
- sync patches and packaging fixes with fedora
- add support for system-wide cipher selection policies

* Sun Jul 30 2017 akien <akien> 1.0.2l-2.mga7
+ Revision: 1132889
- Enable MD2 support necessary for RPM openssl backend

* Fri May 26 2017 akien <akien> 1.0.2l-1.mga6
+ Revision: 1104774
- Version 1.0.2l
- Rediffed P6 (is it still relevant today?)

* Fri Jan 27 2017 luigiwalser <luigiwalser> 1.0.2k-1.mga6
+ Revision: 1083551
- 1.0.2k (fixes CVE-2016-7055 and CVE-2017-373[12])

* Mon Sep 26 2016 luigiwalser <luigiwalser> 1.0.2j-1.mga6
+ Revision: 1057012
- 1.0.2j

* Fri Sep 23 2016 luigiwalser <luigiwalser> 1.0.2i-1.mga6
+ Revision: 1055424
- 1.0.2i

* Mon Jun 06 2016 tv <tv> 1.0.2h-2.mga6
+ Revision: 1020393
- unbloat default install: split out perl scripts

* Tue May 03 2016 luigiwalser <luigiwalser> 1.0.2h-1.mga6
+ Revision: 1009010
- 1.0.2h (fixes CVE-2016-210[5679] and CVE-2016-2176)

* Thu Mar 03 2016 umeabot <umeabot> 1.0.2g-4.mga6
+ Revision: 983854
- Rebuild for openssl

* Wed Mar 02 2016 luigiwalser <luigiwalser> 1.0.2g-3.mga6
+ Revision: 983119
- disable SSLv2 again, it is time to rip the band-aid off

* Wed Mar 02 2016 tmb <tmb> 1.0.2g-2.mga6
+ Revision: 982924
- reenable SSL2 in the build to avoid ABI break

* Tue Mar 01 2016 tmb <tmb> 1.0.2g-1.mga6
+ Revision: 981608
- 1.0.2g (CVE-2016-0702, CVE-2016-0705, CVE-2016-079[7-9], CVE-2016-0800)

* Fri Jan 29 2016 luigiwalser <luigiwalser> 1.0.2f-1.mga6
+ Revision: 928554
- 1.0.2f (fixes CVE-2016-0701 and CVE-2015-3197)

* Sat Jan 02 2016 luigiwalser <luigiwalser> 1.0.2e-3.mga6
+ Revision: 918296
- remove ridiculous obsoletes

* Sat Jan 02 2016 luigiwalser <luigiwalser> 1.0.2e-2.mga6
+ Revision: 918159
- rebuild

* Fri Dec 04 2015 luigiwalser <luigiwalser> 1.0.2e-1.mga6
+ Revision: 908064
- 1.0.2e (fixes CVE-2015-319[3-5] and CVE-2015-1794)
- rediff patch 2

* Fri Aug 21 2015 tmb <tmb> 1.0.2d-2.mga6
+ Revision: 867670
- rebuild for new gcc

* Thu Jul 09 2015 luigiwalser <luigiwalser> 1.0.2d-1.mga6
+ Revision: 853088
- 1.0.2d (fixes CVE-2015-1793)

* Sat Jun 13 2015 luigiwalser <luigiwalser> 1.0.2c-1.mga5
+ Revision: 823035
- 1.0.2c (fixes hmac abi breakage in 1.0.2b)

* Thu Jun 11 2015 luigiwalser <luigiwalser> 1.0.2b-1.mga5
+ Revision: 822986
- 1.0.2b (fixes CVE-2015-4000, CVE-2015-178[89], CVE-2015-179[0-2])
- rediff patch 2

* Thu Mar 19 2015 luigiwalser <luigiwalser> 1.0.2a-1.mga5
+ Revision: 818950
- 1.0.2a
- rediff patches 2, 300, 301

* Fri Feb 20 2015 luigiwalser <luigiwalser> 1.0.2-1.mga5
+ Revision: 816018
- 1.0.2
- rediff patches 2,6,7,12,13,16,17,18,19
- remove bogus patch 15 (mga#15027)

* Fri Jan 16 2015 luigiwalser <luigiwalser> 1.0.1l-1.mga5
+ Revision: 810940
- 1.0.1l

* Thu Jan 08 2015 luigiwalser <luigiwalser> 1.0.1k-1.mga5
+ Revision: 809371
- 1.0.1k

* Thu Oct 23 2014 luigiwalser <luigiwalser> 1.0.1j-2.mga5
+ Revision: 792707
- add patch from fedora to disable SSLv2 and SSLv3 by default

* Wed Oct 15 2014 luigiwalser <luigiwalser> 1.0.1j-1.mga5
+ Revision: 754936
- 1.0.1j
+ umeabot <umeabot>
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.0.1i-2.mga5
+ Revision: 683247
- Mageia 5 Mass Rebuild

* Thu Aug 07 2014 luigiwalser <luigiwalser> 1.0.1i-1.mga5
+ Revision: 660553
- 1.0.1i
- rediff patch 18 (manfix)

* Thu Jun 26 2014 guillomovitch <guillomovitch> 1.0.1h-2.mga5
+ Revision: 639996
- enable accelerated support for the NIST P-224 and P-256 groups (#13269)

* Thu Jun 05 2014 luigiwalser <luigiwalser> 1.0.1h-1.mga5
+ Revision: 633458
- 1.0.1h
- remove upstreamed patches
- update manfix patch from fedora

* Fri May 02 2014 luigiwalser <luigiwalser> 1.0.1g-4.mga5
+ Revision: 619693
- rediff patch from openbsd to fix CVE-2014-0198

* Mon Apr 21 2014 luigiwalser <luigiwalser> 1.0.1g-3.mga5
+ Revision: 617328
- add patch from debian to fix checking critical flag in TSA cert extensions
- add patch from openbsd to fix CVE-2010-5298

* Mon Apr 07 2014 luigiwalser <luigiwalser> 1.0.1g-1.mga5
+ Revision: 612762
- 1.0.1g (fixes CVE-2014-0160)
- remove upstreamed CVE-2014-0076 patch

* Fri Apr 04 2014 luigiwalser <luigiwalser> 1.0.1f-2.mga5
+ Revision: 611712
- add patch from upstream via opensuse to fix CVE-2014-0076

* Tue Feb 04 2014 guillomovitch <guillomovitch> 1.0.1f-1.mga5
+ Revision: 580830
- new version 1.0.1f

* Mon Jan 06 2014 luigiwalser <luigiwalser> 1.0.1e-8.mga4
+ Revision: 565222
- add upstream patch to fix CVE-2013-6450

* Mon Jan 06 2014 guillomovitch <guillomovitch> 1.0.1e-7.mga4
+ Revision: 565179
- use upstream patch to fix CVE 2013-4353

* Mon Dec 23 2013 luigiwalser <luigiwalser> 1.0.1e-6.mga4
+ Revision: 560125
- add patch from fedora to fix CVE-2013-6449

* Mon Oct 28 2013 guillomovitch <guillomovitch> 1.0.1e-5.mga4
+ Revision: 547610
- add upstream patch to fix null pointer issue (mga #11549)

* Mon Oct 21 2013 umeabot <umeabot> 1.0.1e-4.mga4
+ Revision: 540748
- Mageia 4 Mass Rebuild

* Wed Oct 09 2013 guillomovitch <guillomovitch> 1.0.1e-3.mga4
+ Revision: 494272
- disable kerberos support, to fix circular dependency issue (#mga 10339)

* Wed May 29 2013 sander85 <sander85> 1.0.1e-2.mga4
+ Revision: 432014
- fix build of manpages with current pod2man (patches from fedora and upstream)

* Mon Feb 11 2013 luigiwalser <luigiwalser> 1.0.1e-1.mga3
+ Revision: 397936
- 1.0.1e
- remove upstreamed patch

* Fri Feb 08 2013 fwang <fwang> 1.0.1d-1.mga3
+ Revision: 395433
- new version 1.0.1d

* Sun Jan 13 2013 umeabot <umeabot> 1.0.1c-8.mga3
+ Revision: 362158
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Jan 02 2013 guillomovitch <guillomovitch> 1.0.1c-7.mga3
+ Revision: 337612
- re-enable kerberos support

* Wed Jan 02 2013 guillomovitch <guillomovitch> 1.0.1c-6.mga3
+ Revision: 337573
- temporarily disable kerberos support, to be able to build kerberos package without kerberos-devel installed
+ oden <oden>
- small fixes

* Wed Dec 05 2012 guillomovitch <guillomovitch> 1.0.1c-5.mga3
+ Revision: 327008
- use a versionned subdirectory for engines, so as to avoid a file conflict with multiple versions installed simultaneously (spotted by oden)

* Wed Oct 31 2012 guillomovitch <guillomovitch> 1.0.1c-4.mga3
+ Revision: 311718
- fix engines location

* Tue Oct 30 2012 guillomovitch <guillomovitch> 1.0.1c-3.mga3
+ Revision: 311668
- ships engine in a non-versioned directory, as in fedora
+ fwang <fwang>
- lock libmajor

* Thu Jun 07 2012 guillomovitch <guillomovitch> 1.0.1c-2.mga3
+ Revision: 257018
- downgrade lib major, it didn't change

* Thu Jun 07 2012 guillomovitch <guillomovitch> 1.0.1c-1.mga3
+ Revision: 256938
- fix krb5 support, and make it mandatory as in fedora
- new version
- drop outdated pkcs11 engine patch

* Fri May 11 2012 luigiwalser <luigiwalser> 1.0.0j-1.mga2
+ Revision: 235378
- 1.0.0j (fixes CVE-2012-2333)

* Thu Apr 19 2012 guillomovitch <guillomovitch> 1.0.0i-1.mga2
+ Revision: 231806
- new version (fix CVE 2012-2110)

* Tue Mar 13 2012 guillomovitch <guillomovitch> 1.0.0h-1.mga2
+ Revision: 223223
- new version

* Thu Jan 19 2012 fwang <fwang> 1.0.0g-1.mga2
+ Revision: 198045
- new version 1.0.0g

* Thu Jan 05 2012 guillomovitch <guillomovitch> 1.0.0f-1.mga2
+ Revision: 191621
- rename distribution-specific README files to README.mga
- spec cleanup
- drop unapplied conditional patch0, this isn't true anymore
- new version

* Mon Dec 19 2011 fwang <fwang> 1.0.0e-2.mga2
+ Revision: 184360
- enable zlib support

* Wed Sep 07 2011 fwang <fwang> 1.0.0e-1.mga2
+ Revision: 140881
- new version 1.0.0e

* Sun May 15 2011 pterjan <pterjan> 1.0.0d-2.mga1
+ Revision: 99024
- Rebuild for fixed find-requires

* Sat Apr 16 2011 pterjan <pterjan> 1.0.0d-1.mga1
+ Revision: 86203
- Update to 1.0.0d
+ rtp <rtp>
- Fix arm & mips openssl 1.0.0 patches.

* Sat Jan 08 2011 blino <blino> 1.0.0c-2.mga1
+ Revision: 736
- use generic distribution macro
- remove old distro checks
- imported package openssl


* Fri Dec 03 2010 Oden Eriksson <oeriksson@mandriva.com> 1.0.0c-1mdv2011.0
+ Revision: 606171
- 1.0.0b

* Wed Nov 17 2010 Oden Eriksson <oeriksson@mandriva.com> 1.0.0b-1mdv2011.0
+ Revision: 598376
- 1.0.0b (fixes CVE-2010-3864)
- P17: post 1.0.0b fix to make the test suite work after upstream CVE-2010-3864 fixes
- fix small borkiness

* Sat Oct 02 2010 Anssi Hannula <anssi@mandriva.org> 1.0.0a-7mdv2011.0
+ Revision: 582540
- fix versioned obsoletes of openssl-engines (the package was renamed
  in 1.0.0a-5, not 1.0.0a-1.4)

* Mon Sep 20 2010 Oden Eriksson <oeriksson@mandriva.com> 1.0.0a-6mdv2011.0
+ Revision: 579973
- bump release
- fix a dep problem which prevented openssl-engines to be upgraded if both
  x86_64 and i586 urpmi repos were configured.

* Tue Sep 14 2010 Eugeni Dodonov <eugeni@mandriva.com> 1.0.0a-4mdv2011.0
+ Revision: 578251
- Fixed typo in openssl.cnf (#61019)

* Sat Sep 04 2010 Oden Eriksson <oeriksson@mandriva.com> 1.0.0a-3mdv2011.0
+ Revision: 575832
- sync with MDVSA-2010:168

* Wed Jul 14 2010 Matthew Dawkins <mattydaw@mandriva.org> 1.0.0a-2mdv2011.0
+ Revision: 553412
- dropped major for devel & static packages

* Wed Jun 02 2010 Eugeni Dodonov <eugeni@mandriva.com> 1.0.0a-1mdv2010.1
+ Revision: 546943
- Updated to 1.0.0a.

* Tue Apr 06 2010 Eugeni Dodonov <eugeni@mandriva.com> 1.0.0-4mdv2010.1
+ Revision: 532146
- Disable md2 again because it really should not have been enabled.

* Tue Apr 06 2010 Funda Wang <fwang@mandriva.org> 1.0.0-3mdv2010.1
+ Revision: 532115
- enable md2

* Tue Apr 06 2010 Funda Wang <fwang@mandriva.org> 1.0.0-2mdv2010.1
+ Revision: 531959
- obsoletes 0.9.8-static-devel

* Mon Apr 05 2010 Eugeni Dodonov <eugeni@mandriva.com> 1.0.0-1mdv2010.1
+ Revision: 531697
- Updated optflags patches.
- Updated to 1.0.0.
  Rediffed patches.
  Updated pkcs11 patch.

* Fri Mar 26 2010 Eugeni Dodonov <eugeni@mandriva.com> 0.9.8n-1mdv2010.1
+ Revision: 527842
- Updated to 0.9.8n.

* Thu Feb 25 2010 Eugeni Dodonov <eugeni@mandriva.com> 0.9.8m-1mdv2010.1
+ Revision: 511325
- Drop P3 and P9 (no longer needed).
- Updated to 0.9.8m.
  Drop P3, P17-24 (merged upstream).
  Rediff P2, P9, P16.

* Thu Jan 21 2010 Oden Eriksson <oeriksson@mandriva.com> 0.9.8l-2mdv2010.1
+ Revision: 494502
- P24: fix build with binutils-2.20.51.0.x
- P23: security fix for CVE-2009-4355 (upstream)

* Fri Nov 06 2009 Eugeni Dodonov <eugeni@mandriva.com> 0.9.8l-1mdv2010.1
+ Revision: 461230
- Updated to 0.9.8l.
  Fixed static package summary.

* Wed Oct 07 2009 Oden Eriksson <oeriksson@mandriva.com> 0.9.8k-5mdv2010.0
+ Revision: 455585
- P22: fixes a regression with CVE-2009-2409 (#54349)

* Sun Sep 27 2009 Olivier Blin <oblin@mandriva.com> 0.9.8k-4mdv2010.0
+ Revision: 450189
- mips and arm support (from Arnaud Patard)

* Tue Sep 22 2009 Oden Eriksson <oeriksson@mandriva.com> 0.9.8k-3mdv2010.0
+ Revision: 447234
- P19: security fix for CVE-2009-1379
- P20: security fix for CVE-2009-1387
- P21: security fix for CVE-2009-2409

* Thu May 21 2009 Oden Eriksson <oeriksson@mandriva.com> 0.9.8k-2mdv2010.0
+ Revision: 378365
- P17: security fix for CVE-2009-1377
- P18: security fix for CVE-2009-1378

* Thu Mar 26 2009 Eugeni Dodonov <eugeni@mandriva.com> 0.9.8k-1mdv2009.1
+ Revision: 361433
- Updated to 0.9.8k.
  Rediffed P9, P13, P16.
  Dropped P17 (no longer needed) and P18 (merged upstream).

* Tue Feb 03 2009 Guillaume Rousse <guillomovitch@mandriva.org> 0.9.8i-5mdv2009.1
+ Revision: 337119
- keep bash completion in its own package

* Mon Jan 12 2009 Guillaume Rousse <guillomovitch@mandriva.org> 0.9.8i-4mdv2009.1
+ Revision: 328609
- no need to rename man page, we don't ship rsbac anymore
- uncompress additional sources
- bash completion

* Thu Jan 08 2009 Eugeni Dodonov <eugeni@mandriva.com> 0.9.8i-3mdv2009.1
+ Revision: 327021
- P18: security fix for CVE-2008-5077

* Tue Dec 16 2008 Oden Eriksson <oeriksson@mandriva.com> 0.9.8i-2mdv2009.1
+ Revision: 314928
- rediffed fuzzy patches
- fix build with P17 (-Werror=format-security)

* Fri Oct 10 2008 Oden Eriksson <oeriksson@mandriva.com> 0.9.8i-1mdv2009.1
+ Revision: 291331
- 0.9.8i
- dropped the mbstring_flag patch (P4), it's implemented upstream
- added pkcs11 engine support P16

* Thu Aug 07 2008 Thierry Vignaud <tv@mandriva.org> 0.9.8h-3mdv2009.0
+ Revision: 265275
- rebuild early 2009.0 package (before pixel changes)

* Wed Jun 11 2008 Oden Eriksson <oeriksson@mandriva.com> 0.9.8h-2mdv2009.0
+ Revision: 217952
- fix "#%%define is forbidden"
- added P4 to fix borkiness in the apache test suites

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Fri May 30 2008 Oden Eriksson <oeriksson@mandriva.com> 0.9.8h-1mdv2009.0
+ Revision: 213381
- 0.9.8h (fixes CVE-2008-1672, CVE-2008-0891)
- rediffed P2

* Thu May 29 2008 Oden Eriksson <oeriksson@mandriva.com> 0.9.8g-9mdv2009.0
+ Revision: 212968
- P16: security fix for CVE-2008-0891
- P17: security fix for CVE-2008-1672

* Tue May 27 2008 Thierry Vignaud <tv@mandriva.org> 0.9.8g-8mdv2009.0
+ Revision: 211562
- fix duplicated descriptions between devel packages (as showed by latest commits)
- descriptions are not license tags
- remove URLs & emails from descriptions

* Sat May 24 2008 Oden Eriksson <oeriksson@mandriva.com> 0.9.8g-7mdv2009.0
+ Revision: 210856
- rebuild

* Tue May 20 2008 Oden Eriksson <oeriksson@mandriva.com> 0.9.8g-6mdv2009.0
+ Revision: 209328
- rebuilt with gcc43

* Mon Apr 14 2008 Oden Eriksson <oeriksson@mandriva.com> 0.9.8g-5mdv2009.0
+ Revision: 192694
- rebuild
- fix #39792 (openssl-thread-test does not use proper .so file)

* Thu Feb 28 2008 Oden Eriksson <oeriksson@mandriva.com> 0.9.8g-4mdv2008.1
+ Revision: 176382
- rebuild (take 2)

* Thu Feb 28 2008 Oden Eriksson <oeriksson@mandriva.com> 0.9.8g-3mdv2008.1
+ Revision: 176250
- rebuild

* Thu Feb 28 2008 Oden Eriksson <oeriksson@mandriva.com> 0.9.8g-2mdv2008.1
+ Revision: 176044
- fix #38237 (Please include SNI support patch)

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Thu Dec 06 2007 Oden Eriksson <oeriksson@mandriva.com> 0.9.8g-1mdv2008.1
+ Revision: 115942
- bump release
- 0.9.8g

* Fri Oct 19 2007 Oden Eriksson <oeriksson@mandriva.com> 0.9.8f-1mdv2008.1
+ Revision: 100300
- 0.9.8f
- rediffed P2
- drop upstream implemented fixes for CVE-2007-3108, CVE-2007-5135
- drop upstream implemented fixes; P4, P14, P16, P17, P18

* Fri Oct 05 2007 Anne Nicolas <ennael@mandriva.org> 0.9.8e-8mdv2008.0
+ Revision: 95537
- bump release

* Thu Oct 04 2007 Andreas Hasenack <andreas@mandriva.com> 0.9.8e-7mdv2008.0
+ Revision: 95496
- patch to fix security issues CVE-2007-5135 and
  CVE-2007-3108 (#34405 and #32376 respectively)

* Fri Sep 21 2007 Andreas Hasenack <andreas@mandriva.com> 0.9.8e-6mdv2008.0
+ Revision: 91695
- fix sigill during make test (#32769)
- make c_rehash handle .crt extensions (#32621)

  + Thierry Vignaud <tv@mandriva.org>
    - add missing buildrequires for test suite
    - kill file require on perl-base

* Tue Jun 26 2007 Thierry Vignaud <tv@mandriva.org> 0.9.8e-4mdv2008.0
+ Revision: 44488
- rebuild with -fstack-protector

* Tue Apr 24 2007 Andreas Hasenack <andreas@mandriva.com> 0.9.8e-3mdv2008.0
+ Revision: 17927
- fixed 3des cipher bug in openssl (#30431)


* Mon Mar 19 2007 Thierry Vignaud <tvignaud@mandriva.com> 0.9.8e-2mdv2007.1
+ Revision: 146607
- move big doc in -devel

* Mon Feb 26 2007 Andreas Hasenack <andreas@mandriva.com> 0.9.8e-1mdv2007.1
+ Revision: 125816
- updated to version 0.9.8e

* Wed Dec 20 2006 Per Øyvind Karlsen <pkarlsen@mandriva.com> 0.9.8d-3mdv2007.1
+ Revision: 100705
- bump re?\195?\184lease
- fix sparcv9 build
  do not disable asm on sparc
  move checks to %%check

* Mon Dec 11 2006 Gwenole Beauchesne <gbeauchesne@mandriva.com> 0.9.8d-2mdv2007.1
+ Revision: 94733
- 0.9.8d-2mdv
- merge from 2007.0-branch: fix build on ppc64

* Mon Nov 06 2006 Andreas Hasenack <andreas@mandriva.com> 0.9.8d-1mdv2007.1
+ Revision: 77025
- updated to version 0.9.8d
- dropped poll patch, it's already being used upstream
- added new cipher: camellia
- dropped security patches that were already applied

* Tue Oct 31 2006 Oden Eriksson <oeriksson@mandriva.com> 0.9.8b-4mdv2007.1
+ Revision: 74810
- add another patch, phew!
- commit one more patch (duh!)
- commit the patches too...
- bunzip patches

  + Andreas Hasenack <andreas@mandriva.com>
    - added security patches for CVE-2006-2940 (two patches),
      CVE-2006-4343, CVE-2006-3738 and CVE-2006-2937 (#26197)
    - Import openssl

* Thu Sep 07 2006 Oden Eriksson <oeriksson@mandriva.com> 0.9.8b-2
- plug CVE-2006-4339 (#25234)

* Fri May 05 2006 Oden Eriksson <oeriksson@mandriva.com> 0.9.8b-1mdk
- 0.9.8a
- rediffed P3

* Mon Jan 30 2006 Oden Eriksson <oeriksson@mandriva.com> 0.9.8a-10mdk
- fix one conflicting manpage (buffer.3) with rsbac-admin (#20875)

* Fri Jan 27 2006 Oden Eriksson <oeriksson@mandriva.com> 0.9.8a-9mdk
- fix deps (rootcerts)

* Wed Jan 04 2006 Oden Eriksson <oeriksson@mandriva.com> 0.9.8a-8mdk
- fix the /usr/lib6464 error (duh!)

* Wed Jan 04 2006 Oden Eriksson <oeriksson@mandriva.com> 0.9.8a-7mdk
- fix deps

* Mon Dec 05 2005 Oden Eriksson <oeriksson@mandriva.com> 0.9.8a-6mdk
- fix file attribs on certain files in /etc/pki/tls/ (thanks ahasenack)
- fix one missing ";" in the /etc/pki/tls/misc/CA.pl file (thanks ahasenack)
- for the record, 0.9.8a-4mdk fixed #19882

* Wed Nov 23 2005 Christiaan Welvaart <cjw@daneel.dyndns.org> 0.9.8a-5mdk
- add BuildRequires: chrpath

* Mon Nov 21 2005 Oden Eriksson <oeriksson@mandriva.com> 0.9.8a-4mdk
- don't ship a crippled package

* Sat Nov 12 2005 Oden Eriksson <oeriksson@mandriva.com> 0.9.8a-3mdk
- rebuilt due package loss

* Fri Nov 11 2005 Oden Eriksson <oeriksson@mandriva.com> 0.9.8a-2mdk
- added patches and changes from fedora
- OPENSSLDIR is now %%{_sysconfdir}/pki/tls

* Thu Nov 10 2005 Oden Eriksson <oeriksson@mandriva.com> 0.9.8a-1mdk
- merge with the openssl0.9.8 package:
  - 0.9.8a
  - new major
  - rediff P2, P3 and P6

* Mon Oct 17 2005 Oden Eriksson <oeriksson@mandriva.com> 0.9.7i-1mdk
- 0.9.7i (compatibility fix)

* Fri Oct 14 2005 Oden Eriksson <oeriksson@mandriva.com> 0.9.7h-2mdk
- security update for CAN-2005-2946 (P7)

* Wed Oct 12 2005 Oden Eriksson <oeriksson@mandriva.com> 0.9.7h-1mdk
- 0.9.7h (addresses CAN-2005-2969)
- rediff P2,P3

* Fri May 06 2005 Oden Eriksson <oeriksson@mandriva.com> 0.9.7g-2mdk
- rebuilt with gcc4

* Sat Apr 16 2005 Oden Eriksson <oeriksson@mandrakesoft.com> 0.9.7g-1mdk
- 0.9.7g
- rediffed P2

* Fri Apr 01 2005 Oden Eriksson <oeriksson@mandrakesoft.com> 0.9.7f-1mdk
- 0.9.7f
- use the %%mkrel macro
- drop the libfips patch (P5), it's implemented upstream
- drop the CAN-2004-0975 patch (P4) as the code is gone
- rediffed P2

* Wed Mar 02 2005 Oden Eriksson <oeriksson@mandrakesoft.com> 0.9.7e-5mdk
- added P6 to support Brazilian Government OTHERNAME X509v3 field (#14158)

* Mon Jan 31 2005 Oden Eriksson <oeriksson@mandrakesoft.com> 0.9.7e-4mdk
- fix deps and conditional %%multiarch
- added P5 as there's no libfips

* Mon Jan 10 2005 Frederic Lepied <flepied@mandrakesoft.com> 0.9.7e-3mdk
- build in parallel

* Tue Dec 07 2004 Oden Eriksson <oeriksson@mandrakesoft.com> 0.9.7e-2mdk
- apply the CAN-2004-0975 patch (P4) from 0.9.7d-1.1.101mdk

* Mon Nov 08 2004 Oden Eriksson <oeriksson@mandrakesoft.com> 0.9.7e-1mdk
- 0.9.7e
- rediffed P2 & P3
- misc spec file fixes

* Sat Jun 19 2004 Jean-Michel Dault <jmdault@mandrakesoft.com> 0.9.7d-1mdk
- new version
- rediff P3
- remove P4/P5 since they're included in the release

